{*******************************************************}
{                                                       }
{  VG Library II                                        }
{                                                       }
{  VCL Design Editors (ADO)                             }
{                                                       }
{  (c) 1997, 2001 by Vladimir Gaitanoff                 }
{                                                       }
{*******************************************************}

{$I vg2.inc}
{$D-,L-}

unit vg2ADODsgn;

interface
uses DsgnIntf, FldLinks, DBReg,
  vg2ADODB;

type
{ Tvg2ADODataSetEditor }

  Tvg2ADODataSetEditor = class(TDataSetEditor)
  private
    FCanCreate: Boolean;
  public
    procedure ExecuteVerb(Index: Integer); override;
    function GetVerb(Index: Integer): string; override;
    function GetVerbCount: Integer; override;
  end;

{ Tvg2ADODataSetFieldLinkProperty }

  Tvg2ADODataSetFieldLinkProperty = class(TFieldLinkProperty)
  private
    FADODataSet: Tvg2ADODataSet;
  protected
    function GetIndexFieldNames: string; override;
    function GetMasterFields: string; override;
    procedure SetIndexFieldNames(const Value: string); override;
    procedure SetMasterFields(const Value: string); override;
  public
    procedure Edit; override;
  end;

{ Tvg2ADOTableFieldLinkProperty }

  Tvg2ADOTableFieldLinkProperty = class(TFieldLinkProperty)
  private
    FTable: Tvg2ADOTable;
  protected
    function GetIndexFieldNames: string; override;
    function GetMasterFields: string; override;
    procedure SetIndexFieldNames(const Value: string); override;
    procedure SetMasterFields(const Value: string); override;
  public
    procedure Edit; override;
  end;

{ Tvg2ADOUpdateSQLEditor }

  Tvg2ADOUpdateSQLEditor = class(TComponentEditor)
  public
    procedure ExecuteVerb(Index: Integer); override;
    function GetVerb(Index: Integer): string; override;
    function GetVerbCount: Integer; override;
  end;

implementation
uses Consts, DsnDBCst, Dialogs, ADOConst, ADODB,
 vg2DBConsts, vg2ADOSQLEd;

function EditFileName(ADataSet: Tvg2ADODataSet; LoadData: Boolean): Boolean;
begin
  with TOpenDialog.Create(nil) do
  try
    Title := sOpenFileTitle;
    DefaultExt := 'adtg';
    Filter := SADODataFilter;
    Result := Execute;
    if Result then
      if LoadData then
        ADataSet.LoadFromFile(FileName) else
        ADataSet.CommandText := FileName;
  finally
    Free;
  end;
end;

procedure SaveToFile(ADataSet: Tvg2ADODataSet);
var
  PersistFormat: TPersistFormat;
begin
  with TSaveDialog.Create(nil) do
  try
    Options := [ofOverwritePrompt];
    DefaultExt := 'adtg';
    Filter := SADODataFilter;
    if Execute then
    begin
      if FilterIndex = 2 then
        PersistFormat := pfXML else
        PersistFormat := pfADTG;
      ADataSet.SaveToFile(FileName, PersistFormat);
    end;
  finally
    Free;
  end;
end;

procedure Tvg2ADODataSetEditor.ExecuteVerb(Index: Integer);
begin
  if Index <= inherited GetVerbCount - 1 then
    inherited ExecuteVerb(Index) else
  begin
    Dec(Index, inherited GetVerbCount);
    if (Index > 0) and not FCanCreate then Inc(Index);
    case Index of
      0: begin
           EditFileName(Component as Tvg2ADODataSet, True);
           Designer.Modified;
         end;
      1: begin
           Tvg2ADODataSet(Component).CreateDataSet;
           Designer.Modified;
         end;
      2: SaveToFile(Component as Tvg2ADODataSet);
    end;
  end;
end;

function Tvg2ADODataSetEditor.GetVerb(Index: Integer): string;
begin
  if Index <= inherited GetVerbCount - 1 then
    Result := inherited GetVerb(Index) else
  begin
    Dec(Index, inherited GetVerbCount);
    if (Index > 0) and not FCanCreate then Inc(Index);
    case Index of
      0: Result := SLoadFromFile;
      1: Result := SCreateDataSet;
      2: Result := SSaveToFile;
    end;
  end;
end;

function Tvg2ADODataSetEditor.GetVerbCount: Integer;
begin
  Result := inherited GetVerbCount + 1; { LoadFromFile }
  with Tvg2ADODataSet(Component) do
  begin
    FCanCreate := not Active and ((FieldCount > 0) or (FieldDefs.Count > 0));
    { either CreateDataSet or SaveToFile (but never both) }
    if FCanCreate or Active then Inc(Result);
  end;
end;

{ Tvg2ADODataSetFieldLinkProperty }

procedure Tvg2ADODataSetFieldLinkProperty.Edit;
begin
  FADODataSet := DataSet as Tvg2ADODataSet;
  inherited Edit;
end;

function Tvg2ADODataSetFieldLinkProperty.GetIndexFieldNames: string;
begin
  Result := FADODataSet.IndexFieldNames;
end;

function Tvg2ADODataSetFieldLinkProperty.GetMasterFields: string;
begin
  Result := FADODataSet.MasterFields;
end;

procedure Tvg2ADODataSetFieldLinkProperty.SetIndexFieldNames(const Value: string);
begin
  FADODataSet.IndexFieldNames := Value;
end;

procedure Tvg2ADODataSetFieldLinkProperty.SetMasterFields(const Value: string);
begin
  FADODataSet.MasterFields := Value;
end;

{ Tvg2ADOTableFieldLinkProperty }

procedure Tvg2ADOTableFieldLinkProperty.Edit;
begin
  FTable := DataSet as Tvg2ADOTable;
  inherited Edit;
end;

function Tvg2ADOTableFieldLinkProperty.GetIndexFieldNames: string;
begin
  Result := FTable.IndexFieldNames;
end;

function Tvg2ADOTableFieldLinkProperty.GetMasterFields: string;
begin
  Result := FTable.MasterFields;
end;

procedure Tvg2ADOTableFieldLinkProperty.SetIndexFieldNames(const Value: string);
begin
  FTable.IndexFieldNames := Value;
end;

procedure Tvg2ADOTableFieldLinkProperty.SetMasterFields(const Value: string);
begin
  FTable.MasterFields := Value;
end;

{ Tvg2ADOUpdateSQLObjectEditor }

procedure Tvg2ADOUpdateSQLEditor.ExecuteVerb(Index: Integer);
begin
  case Index of
    0: if EditUpdateSQL(Tvg2ADOUpdateSQL(Component)) then
      Designer.Modified;
  end;
end;

function Tvg2ADOUpdateSQLEditor.GetVerb(Index: Integer): string;
begin
  case Index of
    0: Result := SUpdateSQLEditor;
  end;
end;

function Tvg2ADOUpdateSQLEditor.GetVerbCount: Integer;
begin
  Result := 1;
end;


end.
